rough_notation library
Classes
- RoughAnnotationController
- A controller to manually control the start and reset of annotation animations.
- RoughAnnotationRegistry
- Static class to manage grouped annotations and their sequencing logic.
- RoughBoxAnnotation
- Draws a hand-drawn-style sketchy box around the widget.
- RoughBracketAnnotation
- Draws sketchy brackets (left, right, top, bottom) around a widget using hand-drawn-style lines.
- RoughCircleAnnotation
- Draws a rough, hand-drawn style animated circle around a widget.
- RoughCrossedOffAnnotation
- Draws an animated "crossed-off" (X) annotation over a widget.
- RoughHighlightAnnotation
- A sketchy highlight-style annotation behind a widget.
- RoughStrikethroughAnnotation
- A sketchy hand-drawn strikethrough annotation.
- RoughUnderlineAnnotation
- A hand-drawn style underline annotation.