RoughCircleAnnotation class
Draws a rough, hand-drawn style animated circle around a widget.
This annotation uses two SketchArcs rendered by ArcPainter
to simulate the hand-drawn, double-stroke effect seen in the original Rough Notation JS library.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- RoughCircleAnnotation
Constructors
- RoughCircleAnnotation({Key? key, required Widget child, Color color = kCircleColor, double strokeWidth = 2, double? padding, Duration duration = const Duration(milliseconds: 800), Duration delay = Duration.zero, RoughAnnotationController? controller, String? group, int? sequence, int iterations = 2})
-
const
Properties
- child → Widget
-
finalinherited
- color → Color
-
finalinherited
- controller → RoughAnnotationController?
-
finalinherited
- delay → Duration
-
finalinherited
- duration → Duration
-
finalinherited
- group → String?
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- iterations → int
-
finalinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- padding → double?
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sequence → int?
-
finalinherited
- strokeWidth → double
-
finalinherited
Methods
-
buildWithAnimation(
BuildContext context, Animation< double> animation, GlobalKey<State< childKey, int seed, RoughCache cache) → WidgetStatefulWidget> > - Implemented by each annotation to return a widget using the animated value.
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< RoughAnnotation> -
Creates the mutable state for this widget at a given location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited